

JWInstrument
====================

.. currentmodule:: webbpsf

.. autoclass:: JWInstrument
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~JWInstrument.telescope

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: telescope

   
   

   
   
   